@@ -1,12 +1,15 @@
 """
 Defines the project's API endpoints.
 """
+from datetime import datetime, timedelta, timezone
 from typing import Any, Mapping
+from uuid import uuid4
+from zoneinfo import ZoneInfo
 
 import psycopg2
 from flask import Blueprint, Response, request
 from flask_admin.base import render_template
-from jinja2 import Template
+from jinja2 import Environment
 from werkzeug.routing import Map, Rule
 
 from api_reflector import db, models, rules_engine
@@ -18,6 +21,20 @@ api = Blueprint("api", __name__)
 log = get_logger(__name__)
 
 
+template_env = Environment()
+
+
+def convert_to_tz(date_time: datetime, time_zone_name: str) -> datetime:
+    """
+    converts a naive utc datetime to a timezone
+    """
+    date_time = date_time.replace(tzinfo=timezone.utc)
+    return date_time.astimezone(tz=ZoneInfo(time_zone_name))
+
+
+template_env.filters["in_tz"] = convert_to_tz
+
+
 def match_endpoint(path: str) -> tuple[models.Endpoint, Mapping[str, Any]]:
     """
     Uses werkzeug routing to match the given path to an endpoint.
@@ -110,9 +127,12 @@ def mock(path: str) -> Response:
     )
     response = rules_engine.find_best_response(templateable_request, response_rules)
 
-    content = Template(response.content).render(
+    content = template_env.from_string(response.content).render(
         {
             "request": templateable_request,
+            "now": datetime.utcnow,
+            "hours": lambda n: timedelta(hours=n),
+            "guid": lambda: str(uuid4()),
         }
     )
 
